summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttree.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttree.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttree.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttree.h b/kmymoney2/widgets/kmymoneyaccounttree.h
index a4b741d..0b2d1ac 100644
--- a/kmymoney2/widgets/kmymoneyaccounttree.h
+++ b/kmymoney2/widgets/kmymoneyaccounttree.h
@@ -26,8 +26,9 @@ class KMyMoneyAccountTreeItem;
class KMyMoneyAccountTree : public KMyMoneyAccountTreeBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyAccountTree(QWidget* parent = 0, const char *name = 0);
+ KMyMoneyAccountTree(TQWidget* tqparent = 0, const char *name = 0);
int taxReportColumn(void) const { return m_taxReportColumn; }
int vatCategoryColumn(void) const { return m_vatCategoryColumn; }
private:
@@ -42,18 +43,18 @@ public:
* Constructor to be used to construct an institution entry
* object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
* the KListView entry is constructed
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyInstitution& institution);
+ KMyMoneyAccountTreeItem(KListView *tqparent, const MyMoneyInstitution& institution);
/**
* Constructor to be used to construct a standard account entry object (e.g. Asset,
* Liability, etc.).
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -62,13 +63,13 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const QString& name = QString());
+ KMyMoneyAccountTreeItem(KListView *tqparent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
/**
* Constructor to be used to construct an account entry
* object.
*
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -77,7 +78,7 @@ public:
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
*/
- KMyMoneyAccountTreeItem(KMyMoneyAccountTreeBaseItem *parent, const MyMoneyAccount& account, const QValueList<MyMoneyPrice>& price = QValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
+ KMyMoneyAccountTreeItem(KMyMoneyAccountTreeBaseItem *tqparent, const MyMoneyAccount& account, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
void setReconciliation(bool);
@@ -42,18 +43,18 @@ public:
* object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param tqparent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
@@ -42,18 +43,18 @@ public:
* Liability, etc.).
*
- * @param parent pointer to the KListView object this entry should be
+ * @param tqparent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -62,13 +63,13 @@ public:
* object.
*
- * @param parent pointer to the parent KAccountListView object this entry should be
+ * @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which